# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import groups_pb2 as groups__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class GroupsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LoadMembers = channel.unary_unary(
                '/dialog.Groups/LoadMembers',
                request_serializer=groups__pb2.RequestLoadMembers.SerializeToString,
                response_deserializer=groups__pb2.ResponseLoadMembers.FromString,
                )
        self.CreateGroup = channel.unary_unary(
                '/dialog.Groups/CreateGroup',
                request_serializer=groups__pb2.RequestCreateGroup.SerializeToString,
                response_deserializer=groups__pb2.ResponseCreateGroup.FromString,
                )
        self.EditGroupTitle = channel.unary_unary(
                '/dialog.Groups/EditGroupTitle',
                request_serializer=groups__pb2.RequestEditGroupTitle.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
                )
        self.SetGroupShortname = channel.unary_unary(
                '/dialog.Groups/SetGroupShortname',
                request_serializer=groups__pb2.RequestSetGroupShortname.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.EditGroupAvatar = channel.unary_unary(
                '/dialog.Groups/EditGroupAvatar',
                request_serializer=groups__pb2.RequestEditGroupAvatar.SerializeToString,
                response_deserializer=groups__pb2.ResponseEditGroupAvatar.FromString,
                )
        self.RemoveGroupAvatar = channel.unary_unary(
                '/dialog.Groups/RemoveGroupAvatar',
                request_serializer=groups__pb2.RequestRemoveGroupAvatar.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
                )
        self.EditGroupAbout = channel.unary_unary(
                '/dialog.Groups/EditGroupAbout',
                request_serializer=groups__pb2.RequestEditGroupAbout.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
                )
        self.EditGroupBasePermissions = channel.unary_unary(
                '/dialog.Groups/EditGroupBasePermissions',
                request_serializer=groups__pb2.RequestEditGroupBasePermissions.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InviteUser = channel.unary_unary(
                '/dialog.Groups/InviteUser',
                request_serializer=groups__pb2.RequestInviteUser.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
                )
        self.LeaveGroup = channel.unary_unary(
                '/dialog.Groups/LeaveGroup',
                request_serializer=groups__pb2.RequestLeaveGroup.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
                )
        self.KickUser = channel.unary_unary(
                '/dialog.Groups/KickUser',
                request_serializer=groups__pb2.RequestKickUser.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
                )
        self.MakeUserAdmin = channel.unary_unary(
                '/dialog.Groups/MakeUserAdmin',
                request_serializer=groups__pb2.RequestMakeUserAdmin.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
                )
        self.GetGroupMemberPermissions = channel.unary_unary(
                '/dialog.Groups/GetGroupMemberPermissions',
                request_serializer=groups__pb2.RequestGetGroupMemberPermissions.SerializeToString,
                response_deserializer=groups__pb2.ResponseGetGroupMemberPermissions.FromString,
                )
        self.EditMemberPermissions = channel.unary_unary(
                '/dialog.Groups/EditMemberPermissions',
                request_serializer=groups__pb2.RequestEditMemberPermissions.SerializeToString,
                response_deserializer=groups__pb2.ResponseMember.FromString,
                )
        self.TransferOwnership = channel.unary_unary(
                '/dialog.Groups/TransferOwnership',
                request_serializer=groups__pb2.RequestTransferOwnership.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
                )
        self.GetGroupInviteUrl = channel.unary_unary(
                '/dialog.Groups/GetGroupInviteUrl',
                request_serializer=groups__pb2.RequestGetGroupInviteUrl.SerializeToString,
                response_deserializer=groups__pb2.ResponseInviteUrl.FromString,
                )
        self.GetGroupInviteUrlBase = channel.unary_unary(
                '/dialog.Groups/GetGroupInviteUrlBase',
                request_serializer=groups__pb2.RequestGetGroupInviteUrlBase.SerializeToString,
                response_deserializer=groups__pb2.ResponseGetGroupInviteUrlBase.FromString,
                )
        self.RevokeInviteUrl = channel.unary_unary(
                '/dialog.Groups/RevokeInviteUrl',
                request_serializer=groups__pb2.RequestRevokeInviteUrl.SerializeToString,
                response_deserializer=groups__pb2.ResponseInviteUrl.FromString,
                )
        self.JoinGroup = channel.unary_unary(
                '/dialog.Groups/JoinGroup',
                request_serializer=groups__pb2.RequestJoinGroup.SerializeToString,
                response_deserializer=groups__pb2.ResponseJoinGroup.FromString,
                )
        self.JoinGroupByPeer = channel.unary_unary(
                '/dialog.Groups/JoinGroupByPeer',
                request_serializer=groups__pb2.RequestJoinGroupByPeer.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.DeleteGroup = channel.unary_unary(
                '/dialog.Groups/DeleteGroup',
                request_serializer=groups__pb2.RequestDeleteGroup.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetGroupPartialInfo = channel.unary_unary(
                '/dialog.Groups/GetGroupPartialInfo',
                request_serializer=groups__pb2.RequestGetGroupPartialInfo.SerializeToString,
                response_deserializer=groups__pb2.GroupPartialInfo.FromString,
                )


class GroupsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LoadMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditGroupTitle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetGroupShortname(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditGroupAvatar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveGroupAvatar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditGroupAbout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditGroupBasePermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InviteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LeaveGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KickUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakeUserAdmin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupMemberPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditMemberPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferOwnership(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupInviteUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupInviteUrlBase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeInviteUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinGroupByPeer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupPartialInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LoadMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadMembers,
                    request_deserializer=groups__pb2.RequestLoadMembers.FromString,
                    response_serializer=groups__pb2.ResponseLoadMembers.SerializeToString,
            ),
            'CreateGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGroup,
                    request_deserializer=groups__pb2.RequestCreateGroup.FromString,
                    response_serializer=groups__pb2.ResponseCreateGroup.SerializeToString,
            ),
            'EditGroupTitle': grpc.unary_unary_rpc_method_handler(
                    servicer.EditGroupTitle,
                    request_deserializer=groups__pb2.RequestEditGroupTitle.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
            ),
            'SetGroupShortname': grpc.unary_unary_rpc_method_handler(
                    servicer.SetGroupShortname,
                    request_deserializer=groups__pb2.RequestSetGroupShortname.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'EditGroupAvatar': grpc.unary_unary_rpc_method_handler(
                    servicer.EditGroupAvatar,
                    request_deserializer=groups__pb2.RequestEditGroupAvatar.FromString,
                    response_serializer=groups__pb2.ResponseEditGroupAvatar.SerializeToString,
            ),
            'RemoveGroupAvatar': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveGroupAvatar,
                    request_deserializer=groups__pb2.RequestRemoveGroupAvatar.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
            ),
            'EditGroupAbout': grpc.unary_unary_rpc_method_handler(
                    servicer.EditGroupAbout,
                    request_deserializer=groups__pb2.RequestEditGroupAbout.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
            ),
            'EditGroupBasePermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.EditGroupBasePermissions,
                    request_deserializer=groups__pb2.RequestEditGroupBasePermissions.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InviteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.InviteUser,
                    request_deserializer=groups__pb2.RequestInviteUser.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
            ),
            'LeaveGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.LeaveGroup,
                    request_deserializer=groups__pb2.RequestLeaveGroup.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
            ),
            'KickUser': grpc.unary_unary_rpc_method_handler(
                    servicer.KickUser,
                    request_deserializer=groups__pb2.RequestKickUser.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
            ),
            'MakeUserAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.MakeUserAdmin,
                    request_deserializer=groups__pb2.RequestMakeUserAdmin.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
            ),
            'GetGroupMemberPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupMemberPermissions,
                    request_deserializer=groups__pb2.RequestGetGroupMemberPermissions.FromString,
                    response_serializer=groups__pb2.ResponseGetGroupMemberPermissions.SerializeToString,
            ),
            'EditMemberPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.EditMemberPermissions,
                    request_deserializer=groups__pb2.RequestEditMemberPermissions.FromString,
                    response_serializer=groups__pb2.ResponseMember.SerializeToString,
            ),
            'TransferOwnership': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferOwnership,
                    request_deserializer=groups__pb2.RequestTransferOwnership.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
            ),
            'GetGroupInviteUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupInviteUrl,
                    request_deserializer=groups__pb2.RequestGetGroupInviteUrl.FromString,
                    response_serializer=groups__pb2.ResponseInviteUrl.SerializeToString,
            ),
            'GetGroupInviteUrlBase': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupInviteUrlBase,
                    request_deserializer=groups__pb2.RequestGetGroupInviteUrlBase.FromString,
                    response_serializer=groups__pb2.ResponseGetGroupInviteUrlBase.SerializeToString,
            ),
            'RevokeInviteUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeInviteUrl,
                    request_deserializer=groups__pb2.RequestRevokeInviteUrl.FromString,
                    response_serializer=groups__pb2.ResponseInviteUrl.SerializeToString,
            ),
            'JoinGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinGroup,
                    request_deserializer=groups__pb2.RequestJoinGroup.FromString,
                    response_serializer=groups__pb2.ResponseJoinGroup.SerializeToString,
            ),
            'JoinGroupByPeer': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinGroupByPeer,
                    request_deserializer=groups__pb2.RequestJoinGroupByPeer.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'DeleteGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteGroup,
                    request_deserializer=groups__pb2.RequestDeleteGroup.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetGroupPartialInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupPartialInfo,
                    request_deserializer=groups__pb2.RequestGetGroupPartialInfo.FromString,
                    response_serializer=groups__pb2.GroupPartialInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Groups', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Groups(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LoadMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/LoadMembers',
            groups__pb2.RequestLoadMembers.SerializeToString,
            groups__pb2.ResponseLoadMembers.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/CreateGroup',
            groups__pb2.RequestCreateGroup.SerializeToString,
            groups__pb2.ResponseCreateGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditGroupTitle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/EditGroupTitle',
            groups__pb2.RequestEditGroupTitle.SerializeToString,
            miscellaneous__pb2.ResponseSeqDateMid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetGroupShortname(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/SetGroupShortname',
            groups__pb2.RequestSetGroupShortname.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditGroupAvatar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/EditGroupAvatar',
            groups__pb2.RequestEditGroupAvatar.SerializeToString,
            groups__pb2.ResponseEditGroupAvatar.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveGroupAvatar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/RemoveGroupAvatar',
            groups__pb2.RequestRemoveGroupAvatar.SerializeToString,
            miscellaneous__pb2.ResponseSeqDateMid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditGroupAbout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/EditGroupAbout',
            groups__pb2.RequestEditGroupAbout.SerializeToString,
            miscellaneous__pb2.ResponseSeqDate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditGroupBasePermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/EditGroupBasePermissions',
            groups__pb2.RequestEditGroupBasePermissions.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InviteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/InviteUser',
            groups__pb2.RequestInviteUser.SerializeToString,
            miscellaneous__pb2.ResponseSeqDateMid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LeaveGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/LeaveGroup',
            groups__pb2.RequestLeaveGroup.SerializeToString,
            miscellaneous__pb2.ResponseSeqDateMid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KickUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/KickUser',
            groups__pb2.RequestKickUser.SerializeToString,
            miscellaneous__pb2.ResponseSeqDateMid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MakeUserAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/MakeUserAdmin',
            groups__pb2.RequestMakeUserAdmin.SerializeToString,
            miscellaneous__pb2.ResponseSeqDate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupMemberPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/GetGroupMemberPermissions',
            groups__pb2.RequestGetGroupMemberPermissions.SerializeToString,
            groups__pb2.ResponseGetGroupMemberPermissions.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditMemberPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/EditMemberPermissions',
            groups__pb2.RequestEditMemberPermissions.SerializeToString,
            groups__pb2.ResponseMember.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransferOwnership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/TransferOwnership',
            groups__pb2.RequestTransferOwnership.SerializeToString,
            miscellaneous__pb2.ResponseSeqDate.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupInviteUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/GetGroupInviteUrl',
            groups__pb2.RequestGetGroupInviteUrl.SerializeToString,
            groups__pb2.ResponseInviteUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupInviteUrlBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/GetGroupInviteUrlBase',
            groups__pb2.RequestGetGroupInviteUrlBase.SerializeToString,
            groups__pb2.ResponseGetGroupInviteUrlBase.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeInviteUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/RevokeInviteUrl',
            groups__pb2.RequestRevokeInviteUrl.SerializeToString,
            groups__pb2.ResponseInviteUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/JoinGroup',
            groups__pb2.RequestJoinGroup.SerializeToString,
            groups__pb2.ResponseJoinGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinGroupByPeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/JoinGroupByPeer',
            groups__pb2.RequestJoinGroupByPeer.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/DeleteGroup',
            groups__pb2.RequestDeleteGroup.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupPartialInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Groups/GetGroupPartialInfo',
            groups__pb2.RequestGetGroupPartialInfo.SerializeToString,
            groups__pb2.GroupPartialInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import sequence_and_updates_pb2 as sequence__and__updates__pb2


class SequenceAndUpdatesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetState = channel.unary_unary(
                '/dialog.SequenceAndUpdates/GetState',
                request_serializer=sequence__and__updates__pb2.RequestGetState.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.GetDifference = channel.unary_unary(
                '/dialog.SequenceAndUpdates/GetDifference',
                request_serializer=sequence__and__updates__pb2.RequestGetDifference.SerializeToString,
                response_deserializer=sequence__and__updates__pb2.ResponseGetDifference.FromString,
                )
        self.GetDialogsDifference = channel.unary_unary(
                '/dialog.SequenceAndUpdates/GetDialogsDifference',
                request_serializer=sequence__and__updates__pb2.RequestGetDialogsDifference.SerializeToString,
                response_deserializer=sequence__and__updates__pb2.ResponseGetDialogsDifference.FromString,
                )
        self.GetReferencedEntitites = channel.unary_unary(
                '/dialog.SequenceAndUpdates/GetReferencedEntitites',
                request_serializer=sequence__and__updates__pb2.RequestGetReferencedEntitites.SerializeToString,
                response_deserializer=sequence__and__updates__pb2.ResponseGetReferencedEntitites.FromString,
                )
        self.GetPartialPeerInfo = channel.unary_unary(
                '/dialog.SequenceAndUpdates/GetPartialPeerInfo',
                request_serializer=sequence__and__updates__pb2.RequestGetPartialPeerInfo.SerializeToString,
                response_deserializer=sequence__and__updates__pb2.ResponseGetPartialPeerInfo.FromString,
                )
        self.SubscribeToOnline = channel.unary_unary(
                '/dialog.SequenceAndUpdates/SubscribeToOnline',
                request_serializer=sequence__and__updates__pb2.RequestSubscribeToOnline.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SubscribeFromOnline = channel.unary_unary(
                '/dialog.SequenceAndUpdates/SubscribeFromOnline',
                request_serializer=sequence__and__updates__pb2.RequestSubscribeFromOnline.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SubscribeToGroupOnline = channel.unary_unary(
                '/dialog.SequenceAndUpdates/SubscribeToGroupOnline',
                request_serializer=sequence__and__updates__pb2.RequestSubscribeToGroupOnline.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SubscribeFromGroupOnline = channel.unary_unary(
                '/dialog.SequenceAndUpdates/SubscribeFromGroupOnline',
                request_serializer=sequence__and__updates__pb2.RequestSubscribeFromGroupOnline.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.SeqUpdates = channel.unary_stream(
                '/dialog.SequenceAndUpdates/SeqUpdates',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=sequence__and__updates__pb2.SeqUpdateBox.FromString,
                )
        self.WeakUpdates = channel.stream_stream(
                '/dialog.SequenceAndUpdates/WeakUpdates',
                request_serializer=sequence__and__updates__pb2.WeakUpdateCommand.SerializeToString,
                response_deserializer=sequence__and__updates__pb2.WeakUpdateBox.FromString,
                )


class SequenceAndUpdatesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetState(self, request, context):
        """/ Get last seq number
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDifference(self, request, context):
        """/ Get all update that happens after given seq number
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDialogsDifference(self, request, context):
        """/ Load all dialogs that changed after given date
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReferencedEntitites(self, request, context):
        """/ Load some required entities
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPartialPeerInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeToOnline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeFromOnline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeToGroupOnline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeFromGroupOnline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SeqUpdates(self, request, context):
        """/ Get stream of the user's updates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WeakUpdates(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequenceAndUpdatesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetState,
                    request_deserializer=sequence__and__updates__pb2.RequestGetState.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'GetDifference': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDifference,
                    request_deserializer=sequence__and__updates__pb2.RequestGetDifference.FromString,
                    response_serializer=sequence__and__updates__pb2.ResponseGetDifference.SerializeToString,
            ),
            'GetDialogsDifference': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDialogsDifference,
                    request_deserializer=sequence__and__updates__pb2.RequestGetDialogsDifference.FromString,
                    response_serializer=sequence__and__updates__pb2.ResponseGetDialogsDifference.SerializeToString,
            ),
            'GetReferencedEntitites': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReferencedEntitites,
                    request_deserializer=sequence__and__updates__pb2.RequestGetReferencedEntitites.FromString,
                    response_serializer=sequence__and__updates__pb2.ResponseGetReferencedEntitites.SerializeToString,
            ),
            'GetPartialPeerInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPartialPeerInfo,
                    request_deserializer=sequence__and__updates__pb2.RequestGetPartialPeerInfo.FromString,
                    response_serializer=sequence__and__updates__pb2.ResponseGetPartialPeerInfo.SerializeToString,
            ),
            'SubscribeToOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeToOnline,
                    request_deserializer=sequence__and__updates__pb2.RequestSubscribeToOnline.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SubscribeFromOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeFromOnline,
                    request_deserializer=sequence__and__updates__pb2.RequestSubscribeFromOnline.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SubscribeToGroupOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeToGroupOnline,
                    request_deserializer=sequence__and__updates__pb2.RequestSubscribeToGroupOnline.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SubscribeFromGroupOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeFromGroupOnline,
                    request_deserializer=sequence__and__updates__pb2.RequestSubscribeFromGroupOnline.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'SeqUpdates': grpc.unary_stream_rpc_method_handler(
                    servicer.SeqUpdates,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=sequence__and__updates__pb2.SeqUpdateBox.SerializeToString,
            ),
            'WeakUpdates': grpc.stream_stream_rpc_method_handler(
                    servicer.WeakUpdates,
                    request_deserializer=sequence__and__updates__pb2.WeakUpdateCommand.FromString,
                    response_serializer=sequence__and__updates__pb2.WeakUpdateBox.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.SequenceAndUpdates', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SequenceAndUpdates(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/GetState',
            sequence__and__updates__pb2.RequestGetState.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDifference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/GetDifference',
            sequence__and__updates__pb2.RequestGetDifference.SerializeToString,
            sequence__and__updates__pb2.ResponseGetDifference.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDialogsDifference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/GetDialogsDifference',
            sequence__and__updates__pb2.RequestGetDialogsDifference.SerializeToString,
            sequence__and__updates__pb2.ResponseGetDialogsDifference.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReferencedEntitites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/GetReferencedEntitites',
            sequence__and__updates__pb2.RequestGetReferencedEntitites.SerializeToString,
            sequence__and__updates__pb2.ResponseGetReferencedEntitites.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPartialPeerInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/GetPartialPeerInfo',
            sequence__and__updates__pb2.RequestGetPartialPeerInfo.SerializeToString,
            sequence__and__updates__pb2.ResponseGetPartialPeerInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeToOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/SubscribeToOnline',
            sequence__and__updates__pb2.RequestSubscribeToOnline.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeFromOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/SubscribeFromOnline',
            sequence__and__updates__pb2.RequestSubscribeFromOnline.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeToGroupOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/SubscribeToGroupOnline',
            sequence__and__updates__pb2.RequestSubscribeToGroupOnline.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeFromGroupOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.SequenceAndUpdates/SubscribeFromGroupOnline',
            sequence__and__updates__pb2.RequestSubscribeFromGroupOnline.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SeqUpdates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/dialog.SequenceAndUpdates/SeqUpdates',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            sequence__and__updates__pb2.SeqUpdateBox.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WeakUpdates(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/dialog.SequenceAndUpdates/WeakUpdates',
            sequence__and__updates__pb2.WeakUpdateCommand.SerializeToString,
            sequence__and__updates__pb2.WeakUpdateBox.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clickroad.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='clickroad.proto',
  package='clickroad',
  syntax='proto3',
  serialized_options=b'Z\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x63lickroad.proto\x12\tclickroad\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"u\n\x0cTrackContext\x12\x35\n\x07\x63ontext\x18\x01 \x03(\x0b\x32$.clickroad.TrackContext.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x0fTrackScreenView\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x06source\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03url\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x88\x01\n\nTrackEvent\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12+\n\x05label\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"l\n\x0bTrackTiming\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x10\n\x08variable\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\x12+\n\x05label\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\">\n\x0bTrackSocial\x12\x0f\n\x07network\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\",\n\nTrackError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\r\n\x05\x66\x61tal\x18\x02 \x01(\x08\"\xde\x02\n\x0bTrackMetric\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x17.clickroad.TrackContextH\x00\x12\x31\n\x0bscreen_view\x18\x03 \x01(\x0b\x32\x1a.clickroad.TrackScreenViewH\x00\x12&\n\x05\x65vent\x18\x04 \x01(\x0b\x32\x15.clickroad.TrackEventH\x00\x12(\n\x06timing\x18\x05 \x01(\x0b\x32\x16.clickroad.TrackTimingH\x00\x12(\n\x06social\x18\x06 \x01(\x0b\x32\x16.clickroad.TrackSocialH\x00\x12&\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x15.clickroad.TrackErrorH\x00\x12\x18\n\x10\x64\x65\x64uplication_id\x18\x08 \x01(\x03\x42\x08\n\x06metric\"I\n\x11RequestTrackEvent\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\'\n\x07metrics\x18\x02 \x03(\x0b\x32\x16.clickroad.TrackMetric\"!\n\x12ResponseTrackEvent\x12\x0b\n\x03\x63id\x18\x01 \x01(\t2X\n\tClickRoad\x12K\n\nTrackEvent\x12\x1c.clickroad.RequestTrackEvent\x1a\x1d.clickroad.ResponseTrackEvent\"\x00\x42\x08Z\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TRACKCONTEXT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='clickroad.TrackContext.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='clickroad.TrackContext.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clickroad.TrackContext.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=212,
)

_TRACKCONTEXT = _descriptor.Descriptor(
  name='TrackContext',
  full_name='clickroad.TrackContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='context', full_name='clickroad.TrackContext.context', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRACKCONTEXT_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=212,
)


_TRACKSCREENVIEW = _descriptor.Descriptor(
  name='TrackScreenView',
  full_name='clickroad.TrackScreenView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='clickroad.TrackScreenView.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='clickroad.TrackScreenView.source', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='clickroad.TrackScreenView.url', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=334,
)


_TRACKEVENT = _descriptor.Descriptor(
  name='TrackEvent',
  full_name='clickroad.TrackEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='clickroad.TrackEvent.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='clickroad.TrackEvent.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='clickroad.TrackEvent.label', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='clickroad.TrackEvent.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=473,
)


_TRACKTIMING = _descriptor.Descriptor(
  name='TrackTiming',
  full_name='clickroad.TrackTiming',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='clickroad.TrackTiming.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variable', full_name='clickroad.TrackTiming.variable', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='clickroad.TrackTiming.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='clickroad.TrackTiming.label', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=583,
)


_TRACKSOCIAL = _descriptor.Descriptor(
  name='TrackSocial',
  full_name='clickroad.TrackSocial',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='clickroad.TrackSocial.network', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='clickroad.TrackSocial.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='clickroad.TrackSocial.target', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=647,
)


_TRACKERROR = _descriptor.Descriptor(
  name='TrackError',
  full_name='clickroad.TrackError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='clickroad.TrackError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fatal', full_name='clickroad.TrackError.fatal', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=693,
)


_TRACKMETRIC = _descriptor.Descriptor(
  name='TrackMetric',
  full_name='clickroad.TrackMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='clickroad.TrackMetric.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='context', full_name='clickroad.TrackMetric.context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_view', full_name='clickroad.TrackMetric.screen_view', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event', full_name='clickroad.TrackMetric.event', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timing', full_name='clickroad.TrackMetric.timing', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='social', full_name='clickroad.TrackMetric.social', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='clickroad.TrackMetric.error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_id', full_name='clickroad.TrackMetric.deduplication_id', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='metric', full_name='clickroad.TrackMetric.metric',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=696,
  serialized_end=1046,
)


_REQUESTTRACKEVENT = _descriptor.Descriptor(
  name='RequestTrackEvent',
  full_name='clickroad.RequestTrackEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='clickroad.RequestTrackEvent.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='clickroad.RequestTrackEvent.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1121,
)


_RESPONSETRACKEVENT = _descriptor.Descriptor(
  name='ResponseTrackEvent',
  full_name='clickroad.ResponseTrackEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='clickroad.ResponseTrackEvent.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1156,
)

_TRACKCONTEXT_CONTEXTENTRY.containing_type = _TRACKCONTEXT
_TRACKCONTEXT.fields_by_name['context'].message_type = _TRACKCONTEXT_CONTEXTENTRY
_TRACKSCREENVIEW.fields_by_name['source'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKSCREENVIEW.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKEVENT.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKEVENT.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_TRACKTIMING.fields_by_name['label'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TRACKMETRIC.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACKMETRIC.fields_by_name['context'].message_type = _TRACKCONTEXT
_TRACKMETRIC.fields_by_name['screen_view'].message_type = _TRACKSCREENVIEW
_TRACKMETRIC.fields_by_name['event'].message_type = _TRACKEVENT
_TRACKMETRIC.fields_by_name['timing'].message_type = _TRACKTIMING
_TRACKMETRIC.fields_by_name['social'].message_type = _TRACKSOCIAL
_TRACKMETRIC.fields_by_name['error'].message_type = _TRACKERROR
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['context'])
_TRACKMETRIC.fields_by_name['context'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['screen_view'])
_TRACKMETRIC.fields_by_name['screen_view'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['event'])
_TRACKMETRIC.fields_by_name['event'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['timing'])
_TRACKMETRIC.fields_by_name['timing'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['social'])
_TRACKMETRIC.fields_by_name['social'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_TRACKMETRIC.oneofs_by_name['metric'].fields.append(
  _TRACKMETRIC.fields_by_name['error'])
_TRACKMETRIC.fields_by_name['error'].containing_oneof = _TRACKMETRIC.oneofs_by_name['metric']
_REQUESTTRACKEVENT.fields_by_name['metrics'].message_type = _TRACKMETRIC
DESCRIPTOR.message_types_by_name['TrackContext'] = _TRACKCONTEXT
DESCRIPTOR.message_types_by_name['TrackScreenView'] = _TRACKSCREENVIEW
DESCRIPTOR.message_types_by_name['TrackEvent'] = _TRACKEVENT
DESCRIPTOR.message_types_by_name['TrackTiming'] = _TRACKTIMING
DESCRIPTOR.message_types_by_name['TrackSocial'] = _TRACKSOCIAL
DESCRIPTOR.message_types_by_name['TrackError'] = _TRACKERROR
DESCRIPTOR.message_types_by_name['TrackMetric'] = _TRACKMETRIC
DESCRIPTOR.message_types_by_name['RequestTrackEvent'] = _REQUESTTRACKEVENT
DESCRIPTOR.message_types_by_name['ResponseTrackEvent'] = _RESPONSETRACKEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackContext = _reflection.GeneratedProtocolMessageType('TrackContext', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRACKCONTEXT_CONTEXTENTRY,
    '__module__' : 'clickroad_pb2'
    # @@protoc_insertion_point(class_scope:clickroad.TrackContext.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _TRACKCONTEXT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackContext)
  })
_sym_db.RegisterMessage(TrackContext)
_sym_db.RegisterMessage(TrackContext.ContextEntry)

TrackScreenView = _reflection.GeneratedProtocolMessageType('TrackScreenView', (_message.Message,), {
  'DESCRIPTOR' : _TRACKSCREENVIEW,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackScreenView)
  })
_sym_db.RegisterMessage(TrackScreenView)

TrackEvent = _reflection.GeneratedProtocolMessageType('TrackEvent', (_message.Message,), {
  'DESCRIPTOR' : _TRACKEVENT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackEvent)
  })
_sym_db.RegisterMessage(TrackEvent)

TrackTiming = _reflection.GeneratedProtocolMessageType('TrackTiming', (_message.Message,), {
  'DESCRIPTOR' : _TRACKTIMING,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackTiming)
  })
_sym_db.RegisterMessage(TrackTiming)

TrackSocial = _reflection.GeneratedProtocolMessageType('TrackSocial', (_message.Message,), {
  'DESCRIPTOR' : _TRACKSOCIAL,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackSocial)
  })
_sym_db.RegisterMessage(TrackSocial)

TrackError = _reflection.GeneratedProtocolMessageType('TrackError', (_message.Message,), {
  'DESCRIPTOR' : _TRACKERROR,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackError)
  })
_sym_db.RegisterMessage(TrackError)

TrackMetric = _reflection.GeneratedProtocolMessageType('TrackMetric', (_message.Message,), {
  'DESCRIPTOR' : _TRACKMETRIC,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.TrackMetric)
  })
_sym_db.RegisterMessage(TrackMetric)

RequestTrackEvent = _reflection.GeneratedProtocolMessageType('RequestTrackEvent', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTTRACKEVENT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.RequestTrackEvent)
  })
_sym_db.RegisterMessage(RequestTrackEvent)

ResponseTrackEvent = _reflection.GeneratedProtocolMessageType('ResponseTrackEvent', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSETRACKEVENT,
  '__module__' : 'clickroad_pb2'
  # @@protoc_insertion_point(class_scope:clickroad.ResponseTrackEvent)
  })
_sym_db.RegisterMessage(ResponseTrackEvent)


DESCRIPTOR._options = None
_TRACKCONTEXT_CONTEXTENTRY._options = None

_CLICKROAD = _descriptor.ServiceDescriptor(
  name='ClickRoad',
  full_name='clickroad.ClickRoad',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1158,
  serialized_end=1246,
  methods=[
  _descriptor.MethodDescriptor(
    name='TrackEvent',
    full_name='clickroad.ClickRoad.TrackEvent',
    index=0,
    containing_service=None,
    input_type=_REQUESTTRACKEVENT,
    output_type=_RESPONSETRACKEVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLICKROAD)

DESCRIPTOR.services_by_name['ClickRoad'] = _CLICKROAD

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import miniappsregistry_pb2 as miniappsregistry__pb2


class ClientsMiniAppsRegistryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindApp = channel.unary_unary(
                '/dialog.ClientsMiniAppsRegistry/FindApp',
                request_serializer=miniappsregistry__pb2.FindAppRequest.SerializeToString,
                response_deserializer=miniappsregistry__pb2.FindAppResponse.FromString,
                )
        self.GetApps = channel.unary_unary(
                '/dialog.ClientsMiniAppsRegistry/GetApps',
                request_serializer=miniappsregistry__pb2.GetAppsRequest.SerializeToString,
                response_deserializer=miniappsregistry__pb2.GetAppsResponse.FromString,
                )
        self.GetExtensions = channel.unary_unary(
                '/dialog.ClientsMiniAppsRegistry/GetExtensions',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=miniappsregistry__pb2.GetExtensionsResponse.FromString,
                )
        self.IssueAccessToken = channel.unary_unary(
                '/dialog.ClientsMiniAppsRegistry/IssueAccessToken',
                request_serializer=miniappsregistry__pb2.IssueAccessTokenRequest.SerializeToString,
                response_deserializer=miniappsregistry__pb2.AccessTokenResponse.FromString,
                )


class ClientsMiniAppsRegistryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtensions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IssueAccessToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClientsMiniAppsRegistryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindApp': grpc.unary_unary_rpc_method_handler(
                    servicer.FindApp,
                    request_deserializer=miniappsregistry__pb2.FindAppRequest.FromString,
                    response_serializer=miniappsregistry__pb2.FindAppResponse.SerializeToString,
            ),
            'GetApps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApps,
                    request_deserializer=miniappsregistry__pb2.GetAppsRequest.FromString,
                    response_serializer=miniappsregistry__pb2.GetAppsResponse.SerializeToString,
            ),
            'GetExtensions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtensions,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=miniappsregistry__pb2.GetExtensionsResponse.SerializeToString,
            ),
            'IssueAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.IssueAccessToken,
                    request_deserializer=miniappsregistry__pb2.IssueAccessTokenRequest.FromString,
                    response_serializer=miniappsregistry__pb2.AccessTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.ClientsMiniAppsRegistry', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClientsMiniAppsRegistry(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ClientsMiniAppsRegistry/FindApp',
            miniappsregistry__pb2.FindAppRequest.SerializeToString,
            miniappsregistry__pb2.FindAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ClientsMiniAppsRegistry/GetApps',
            miniappsregistry__pb2.GetAppsRequest.SerializeToString,
            miniappsregistry__pb2.GetAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtensions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ClientsMiniAppsRegistry/GetExtensions',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            miniappsregistry__pb2.GetExtensionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IssueAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ClientsMiniAppsRegistry/IssueAccessToken',
            miniappsregistry__pb2.IssueAccessTokenRequest.SerializeToString,
            miniappsregistry__pb2.AccessTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: device_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='device_info.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x64\x65vice_info.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\"\xa8\x01\n\x1cRequestNotifyAboutDeviceInfo\x12*\n\x13preferred_languages\x18\x01 \x03(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xf8\x02\n\nClientInfo\x12\x35\n\x08platform\x18\x01 \x01(\x0e\x32\x14.dialog.PlatformTypeB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1f\n\x08\x61pp_name\x18\x03 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0b\x61pp_version\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x0bsdk_version\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x06 \x03(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible*\x9c\x01\n\x0cPlatformType\x12\x18\n\x14PLATFORMTYPE_UNKNOWN\x10\x00\x12\x18\n\x14PLATFORMTYPE_ANDROID\x10\x01\x12\x14\n\x10PLATFORMTYPE_IOS\x10\x02\x12\x14\n\x10PLATFORMTYPE_WEB\x10\x03\x12\x14\n\x10PLATFORMTYPE_CLC\x10\x04\x12\x16\n\x12PLATFORMTYPE_TESTS\x10*2\x98\x01\n\nDeviceInfo\x12\x89\x01\n\x15NotifyAboutDeviceInfo\x12$.dialog.RequestNotifyAboutDeviceInfo\x1a\x14.dialog.ResponseVoid\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/DeviceInfo/NotifyAboutDeviceInfo:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_PLATFORMTYPE = _descriptor.EnumDescriptor(
  name='PlatformType',
  full_name='dialog.PlatformType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLATFORMTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATFORMTYPE_ANDROID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATFORMTYPE_IOS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATFORMTYPE_WEB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATFORMTYPE_CLC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATFORMTYPE_TESTS', index=5, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=705,
  serialized_end=861,
)
_sym_db.RegisterEnumDescriptor(_PLATFORMTYPE)

PlatformType = enum_type_wrapper.EnumTypeWrapper(_PLATFORMTYPE)
PLATFORMTYPE_UNKNOWN = 0
PLATFORMTYPE_ANDROID = 1
PLATFORMTYPE_IOS = 2
PLATFORMTYPE_WEB = 3
PLATFORMTYPE_CLC = 4
PLATFORMTYPE_TESTS = 42



_REQUESTNOTIFYABOUTDEVICEINFO = _descriptor.Descriptor(
  name='RequestNotifyAboutDeviceInfo',
  full_name='dialog.RequestNotifyAboutDeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestNotifyAboutDeviceInfo.preferred_languages', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.RequestNotifyAboutDeviceInfo.time_zone', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=323,
)


_CLIENTINFO = _descriptor.Descriptor(
  name='ClientInfo',
  full_name='dialog.ClientInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='platform', full_name='dialog.ClientInfo.platform', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='dialog.ClientInfo.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='dialog.ClientInfo.app_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='dialog.ClientInfo.app_version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdk_version', full_name='dialog.ClientInfo.sdk_version', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.ClientInfo.preferred_languages', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.ClientInfo.time_zone', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=702,
)

_REQUESTNOTIFYABOUTDEVICEINFO.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLIENTINFO.fields_by_name['platform'].enum_type = _PLATFORMTYPE
_CLIENTINFO.fields_by_name['app_version'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLIENTINFO.fields_by_name['sdk_version'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLIENTINFO.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['RequestNotifyAboutDeviceInfo'] = _REQUESTNOTIFYABOUTDEVICEINFO
DESCRIPTOR.message_types_by_name['ClientInfo'] = _CLIENTINFO
DESCRIPTOR.enum_types_by_name['PlatformType'] = _PLATFORMTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestNotifyAboutDeviceInfo = _reflection.GeneratedProtocolMessageType('RequestNotifyAboutDeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTNOTIFYABOUTDEVICEINFO,
  '__module__' : 'device_info_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestNotifyAboutDeviceInfo)
  })
_sym_db.RegisterMessage(RequestNotifyAboutDeviceInfo)

ClientInfo = _reflection.GeneratedProtocolMessageType('ClientInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTINFO,
  '__module__' : 'device_info_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ClientInfo)
  })
_sym_db.RegisterMessage(ClientInfo)


DESCRIPTOR._options = None
_REQUESTNOTIFYABOUTDEVICEINFO.fields_by_name['preferred_languages']._options = None
_REQUESTNOTIFYABOUTDEVICEINFO.fields_by_name['time_zone']._options = None
_REQUESTNOTIFYABOUTDEVICEINFO._options = None
_CLIENTINFO.fields_by_name['platform']._options = None
_CLIENTINFO.fields_by_name['device_name']._options = None
_CLIENTINFO.fields_by_name['app_name']._options = None
_CLIENTINFO.fields_by_name['app_version']._options = None
_CLIENTINFO.fields_by_name['sdk_version']._options = None
_CLIENTINFO.fields_by_name['preferred_languages']._options = None
_CLIENTINFO.fields_by_name['time_zone']._options = None

_DEVICEINFO = _descriptor.ServiceDescriptor(
  name='DeviceInfo',
  full_name='dialog.DeviceInfo',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=864,
  serialized_end=1016,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyAboutDeviceInfo',
    full_name='dialog.DeviceInfo.NotifyAboutDeviceInfo',
    index=0,
    containing_service=None,
    input_type=_REQUESTNOTIFYABOUTDEVICEINFO,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002.\")/v1/grpc/DeviceInfo/NotifyAboutDeviceInfo:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEVICEINFO)

DESCRIPTOR.services_by_name['DeviceInfo'] = _DEVICEINFO

# @@protoc_insertion_point(module_scope)
